cmoncrawl.aggregator.index\_query.IndexAggregator.get\_all\_CC\_indexes
=======================================================================

.. currentmodule:: cmoncrawl.aggregator.index_query

.. automethod:: IndexAggregator.get_all_CC_indexes